#[non_exhaustive]pub enum Kind {
File,
Direct,
}Expand description
Kind of descriptor.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
File
Regular Unix file descriptor.
Direct
Direct descriptor are io_uring private file descriptor.
They avoid some of the overhead associated with thread shared file tables and can be used in any io_uring request that takes a file descriptor. However they cannot be used outside of io_uring.